<?php
/**
 * Autoplay Theme Customizer
 */

// Loads custom control
require trailingslashit( get_template_directory() ) . 'inc/customizer/custom/text.php';

// Loads the customizer options
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/retina-logo.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/general.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/header.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/archive.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/post.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/page.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/trending.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/views.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/footer.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/fonts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/colors.php';

/**
 * Custom customizer functions.
 */
function autoplay_customize_functions( $wp_customize ) {

	// Register new panel: Theme Options
	$wp_customize->add_panel( 'autoplay_options', array(
		'title'       => esc_html__( 'Theme Options', 'autoplay' ),
		'description' => esc_html__( 'This panel is used for customizing the Autoplay theme.', 'autoplay' ),
		'priority'    => 130,
	) );

	// Live preview of Site Title
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

	// Enable selective refresh to the Site Title
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'            => '.site-title a',
			'settings'         => array( 'blogname' ),
			'render_callback'  => function() {
				return get_bloginfo( 'name', 'display' );
			}
		) );
	}

	// Move the Colors section.
	$wp_customize->get_section( 'colors' )->panel    = 'autoplay_options';
	$wp_customize->get_section( 'colors' )->priority = 2;

	// Move the Theme Layout
	// $wp_customize->get_section( 'layout' )->panel    = 'autoplay_options';
	// $wp_customize->get_section( 'layout' )->title    = esc_html__( 'Layouts', 'autoplay' );
	// $wp_customize->get_section( 'layout' )->priority = 5;
	// $wp_customize->get_control( 'theme-layout-control' )->label    = esc_html__( 'Post / Page Layout', 'autoplay' );
	// $wp_customize->get_control( 'theme-layout-control' )->priority = 1;
	// $wp_customize->get_control( 'theme-layout-control' )->active_callback = function() {
	// 	return is_page() || is_single();
	// };

	// Move the Background Image section.
	$wp_customize->get_section( 'background_image' )->panel    = 'autoplay_options';
	$wp_customize->get_section( 'background_image' )->priority = 3;

	// Move background color to background image section.
	$wp_customize->get_section( 'background_image' )->title = esc_html__( 'Background', 'autoplay' );
	$wp_customize->get_control( 'background_color' )->section = 'background_image';


}
add_action( 'customize_register', 'autoplay_customize_functions', 99 );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function autoplay_customize_preview_js() {
	wp_enqueue_script( 'autoplay-customizer', get_template_directory_uri() . '/inc/customizer/assets/js/preview.js', array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'autoplay_customize_preview_js' );

/**
 * Display theme documentation on customizer page.
 */
function autoplay_documentation_link() {

	// Enqueue the script
	wp_enqueue_script( 'autoplay-doc', get_template_directory_uri() . '/inc/customizer/assets/js/doc.js', array(), '1.0.0', true );

	// Localize the script
	wp_localize_script( 'autoplay-doc', 'autoplayL10n',
		array(
			'autoplayURL'   => esc_url( 'http://docs.theme-junkie.com/autoplay/' ),
			'autoplayLabel' => esc_html__( 'Documentation', 'autoplay' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'autoplay_documentation_link' );
