<?php
/**
 * Footer Customizer
 */

/**
 * Register the customizer.
 */
function autoplay_footer_customize_register( $wp_customize ) {

	// Register new section: Footer
	$wp_customize->add_section( 'autoplay_footer' , array(
		'title'    => esc_html__( 'Footer', 'autoplay' ),
		'panel'    => 'autoplay_options',
		'priority' => 17
	) );

	// Register footer branding setting
	$wp_customize->add_setting( 'autoplay_footer_logo', array(
		'default'           => '',
		'sanitize_callback' => 'absint'
	) );
	$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'autoplay_footer_logo', array(
		'label'             => esc_html__( 'Logo', 'autoplay' ),
		'section'           => 'autoplay_footer',
		'priority'          => 1,
		'flex_width'        => true,
		'flex_height'       => true,
		'width'             => 250,
		'height'            => 70
	) ) );

	// Register retina footer branding setting
	$wp_customize->add_setting( 'autoplay_retina_footer_logo', array(
		'default'           => '',
		'sanitize_callback' => 'absint'
	) );
	$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'autoplay_retina_footer_logo', array(
		'label'             => esc_html__( 'Retina Logo', 'autoplay' ),
		'section'           => 'autoplay_footer',
		'priority'          => 3,
		'flex_width'        => true,
		'flex_height'       => true,
		'width'             => 500,
		'height'            => 140
	) ) );

	// Register footer background image setting
	$wp_customize->add_setting( 'autoplay_footer_bg_image', array(
		'default'           => '',
		'sanitize_callback' => 'absint'
	) );
	$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'autoplay_footer_bg_image', array(
		'label'             => esc_html__( 'Backgroud Image', 'autoplay' ),
		'section'           => 'autoplay_footer',
		'priority'          => 5,
		'flex_width'        => true,
		'flex_height'       => true,
		'width'             => 1920,
		'height'            => 600
	) ) );

	// Register footer background color setting
	$wp_customize->add_setting( 'autoplay_footer_bg_color', array(
		'default'           => '#333333',
		'sanitize_callback' => 'autoplay_sanitize_hex_color',
		'transport'         => 'postMessage'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'autoplay_footer_bg_color', array(
		'label'             => esc_html__( 'Background color', 'autoplay' ),
		'section'           => 'autoplay_footer',
		'priority'          => 7
	) ) );

	// Register footer widget column setting
	$wp_customize->add_setting( 'autoplay_footer_widget_column', array(
		'default'           => '4',
		'sanitize_callback' => 'autoplay_sanitize_select',
	) );
	$wp_customize->add_control( 'autoplay_footer_widget_column', array(
		'label'             => esc_html__( 'Footer Widget Columns', 'autoplay' ),
		'section'           => 'autoplay_footer',
		'priority'          => 9,
		'type'              => 'radio',
		'choices'           => array(
			'3' => esc_html__( '3 Columns', 'autoplay' ),
			'4' => esc_html__( '4 Columns', 'autoplay' ),
			'6' => esc_html__( '6 Columns', 'autoplay' )
		)
	) );

	// Register Footer Credits setting
	$wp_customize->add_setting( 'autoplay_footer_credits', array(
		'sanitize_callback' => 'autoplay_sanitize_html',
		'default'           => '&copy; Copyright ' . date( 'Y' ) . ' <a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a> &middot; Designed and Developed by <a href="http://www.theme-junkie.com/">Theme Junkie</a>',
		'transport'         => 'postMessage',
	) );
	$wp_customize->add_control( 'autoplay_footer_credits', array(
		'label'             => esc_html__( 'Footer Text', 'autoplay' ),
		'section'           => 'autoplay_footer',
		'priority'          => 11,
		'type'              => 'textarea'
	) );
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'autoplay_footer_credits', array(
			'selector'         => '.copyright',
			'settings'         => array( 'autoplay_footer_credits' ),
			'render_callback'  => function() {
				return autoplay_sanitize_html( get_theme_mod( 'autoplay_footer_credits' ) );
			}
		) );
	}

}
add_action( 'customize_register', 'autoplay_footer_customize_register' );
